@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use Carp;
 use HTTP::Request::Common;
@@ -162,37 +162,34 @@ sub get_credits
 	$_[0]->transaction ( txn => "get_credits" );
 }
 
-=head1
-
-send_sms - send an SMS text message
-
-required parameters
-	message: max 160 chars, 280 for 8bit
-	msisdn: comma separated list of recipient phone numbers
-
-optional parameters
-	sender: sender id (if alphanumeric, max 11 characters). This facility has to be specifically enabled for your account on request. Alphanumeric sender id is a route-specific feature. 
-	msg_class: currently 0 (flash SMS) or 2 (normal SMS), default 2 
-	dca: Data Coding Alphabet: 7bit,8bit or 16bit, default 7bit (normal text message). For 8bit (ringtones,logos) or 16bit (Unicode), a message containing only hexadecimal octets, to a maximum of 280 characters (140 octet pairs), must be submitted. Currently, concatenation is not supported for Unicode messages. 16-bit is a route-specific feature. 
-	want_report: 0 or 1, default 0 
-	cost_route: 1 or 2, default 1 (future functionality - always use 1 for now, if used) 
-	msg_id: a unique id generated by yourself, to reduce risk of duplicate submissions - future functionality, currently unused. 
-
-returns
-	status_code|status_description|message_id (where message_id is optional, depending on the error) 
-
-status codes
-	0: In progress (a normal message submission, with no error encountered so far). 
-	22: Internal fatal error 
-	23: Authentication failure 
-	24: Data validation failed 
-	25: You do not have sufficient credits 
-	26: Upstream credits not available 
-	27: You have exceeded your daily quota 
-	28: Upstream quota exceeded 
-	40: Temporarily unavailable 
-
-=cut
+# send_sms - send an SMS text message
+# 
+# required parameters
+# 	message: max 160 chars, 280 for 8bit
+# 	msisdn: comma separated list of recipient phone numbers
+# 
+# optional parameters
+# 	sender: sender id (if alphanumeric, max 11 characters). This facility has to be specifically enabled for your account on request. Alphanumeric sender id is a route-specific feature. 
+# 	msg_class: currently 0 (flash SMS) or 2 (normal SMS), default 2 
+# 	dca: Data Coding Alphabet: 7bit,8bit or 16bit, default 7bit (normal text message). For 8bit (ringtones,logos) or 16bit (Unicode), a message containing only hexadecimal octets, to a maximum of 280 characters (140 octet pairs), must be submitted. Currently, concatenation is not supported for Unicode messages. 16-bit is a route-specific feature. 
+# 	want_report: 0 or 1, default 0 
+# 	cost_route: 1 or 2, default 1 (future functionality - always use 1 for now, if used) 
+# 	msg_id: a unique id generated by yourself, to reduce risk of duplicate submissions - future functionality, currently unused. 
+# 
+# returns
+#	 status_code|status_description|message_id (where message_id is optional, depending on the error) 
+# 
+# status codes
+# 	0: In progress (a normal message submission, with no error encountered so far). 
+# 	22: Internal fatal error 
+# 	23: Authentication failure 
+# 	24: Data validation failed 
+# 	25: You do not have sufficient credits 
+# 	26: Upstream credits not available 
+# 	27: You have exceeded your daily quota 
+# 	28: Upstream quota exceeded 
+# 	40: Temporarily unavailable 
+# 
 
 sub base_send_sms
 {
@@ -269,57 +266,53 @@ sub quote_sms
 	return ("$code: $desc",0); # failure
 }
 
-=head1
-
-get_report - report status of a sent SMS text message
-
-required parameters
-	msg_id: message id return by send_sms
-optional parameter
-	msisdn: supply if querying the status of a single recipient. 
-
-returns on failure
-	desc: "request_status_code: desc" formatted request status code and description
-	code: 0
-	result: undefined
-
-	possible request status codes
-		23: Authentication failure 
-		24: Data validation failed 
-		1001: Error - message not found (msg_id incorrect)
-
-returns on success
-	desc: "request status code: description", code 1000, description
-				"Results to follow\n" followed by one or more newline-separated items in the format:
-				"msisdn|status_code|status_description"
-	code: 1
-	result: pointer to results hash indexed by msisdn (phone number),
-		each entry a pointer to hash of {code,desc}
-	
-status codes and descriptions:
-
-	0: In progress (a normal message submission, with no error encountered so far). 
-	10: Delivered upstream 
-	11: Delivered to mobile 
-	22: Internal fatal error 
-	23: Authentication failure 
-	24: Data validation failed 
-	25: You do not have sufficient credits 
-	26: Upstream credits not available 
-	27: You have exceeded your daily quota 
-	28: Upstream quota exceeded 
-	29: Message sending cancelled 
-	30: Test complete (you should never see this) 
-	40: Temporarily unavailable 
-	50: Delivery failed - generic failure 
-	51: Delivery to phone failed 
-	52: Delivery to network failed 
-	60: Transient upstream failure (transient) 
-	61: Upstream status update (transient) 
-	62: Upstream cancel failed (transient) 
-	70: Unknown upstream status 
-
-=cut
+# get_report - report status of a sent SMS text message
+# 
+# required parameters
+# 	msg_id: message id return by send_sms
+# optional parameter
+# 	msisdn: supply if querying the status of a single recipient. 
+# 
+# returns on failure
+# 	desc: "request_status_code: desc" formatted request status code and description
+# 	code: 0
+# 	result: undefined
+# 
+# 	possible request status codes
+# 		23: Authentication failure 
+# 		24: Data validation failed 
+# 		1001: Error - message not found (msg_id incorrect)
+# 
+# returns on success
+# 	desc: "request status code: description", code 1000, description
+# 				"Results to follow\n" followed by one or more newline-separated items in the format:
+# 				"msisdn|status_code|status_description"
+# 	code: 1
+# 	result: pointer to results hash indexed by msisdn (phone number),
+# 		each entry a pointer to hash of {code,desc}
+# 	
+# status codes and descriptions:
+# 
+# 	0: In progress (a normal message submission, with no error encountered so far). 
+# 	10: Delivered upstream 
+# 	11: Delivered to mobile 
+# 	22: Internal fatal error 
+# 	23: Authentication failure 
+# 	24: Data validation failed 
+# 	25: You do not have sufficient credits 
+# 	26: Upstream credits not available 
+# 	27: You have exceeded your daily quota 
+# 	28: Upstream quota exceeded 
+# 	29: Message sending cancelled 
+# 	30: Test complete (you should never see this) 
+# 	40: Temporarily unavailable 
+# 	50: Delivery failed - generic failure 
+# 	51: Delivery to phone failed 
+# 	52: Delivery to network failed 
+# 	60: Transient upstream failure (transient) 
+# 	61: Upstream status update (transient) 
+# 	62: Upstream cancel failed (transient) 
+# 	70: Unknown upstream status 
 
 sub get_report
 {
@@ -544,11 +537,11 @@ L<MIME::Base64>
 
 =head1 AUTHOR
 
-C<Net::SMS::BulkSMS> was developed by Peter Edwards <peterdragon@users.sourceforge.net>.
+C<Net::SMS::BulkSMS> was developed by Peter Edwards <peter@dragonstaff.co.uk>.
 
 =head1 COPYRIGHT
 
-Copyright 2006 Peter Edwards <peterdragon@users.sourceforge.net>.
+Copyright 2007 Peter Edwards <peter@dragonstaff.co.uk>.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
